@@ -54,6 +54,7 @@
 #define RDFS_SUB_PROPERTY_OF RDFS_PREFIX "subPropertyOf"
 
 #define NRL_PREFIX TRACKER_NRL_PREFIX
+#define NRL_INVERSE_FUNCTIONAL_PROPERTY TRACKER_NRL_PREFIX "InverseFunctionalProperty"
 #define NRL_MAX_CARDINALITY NRL_PREFIX "maxCardinality"
 
 #define TRACKER_PREFIX TRACKER_TRACKER_PREFIX
@@ -108,6 +109,16 @@ load_ontology_file_from_path (const gchar	 *ontology_file)
 				tracker_property_set_uri (property, subject);
 				tracker_ontology_add_property (property);
 				g_object_unref (property);
+			} else if (g_strcmp0 (object, NRL_INVERSE_FUNCTIONAL_PROPERTY) == 0) {
+				TrackerProperty *property;
+
+				property = tracker_ontology_get_property_by_uri (subject);
+				if (property == NULL) {
+					g_critical ("%s: Unknown property %s", ontology_file, subject);
+					continue;
+				}
+
+				tracker_property_set_is_inverse_functional_property (property, TRUE);
 			} else if (g_strcmp0 (object, TRACKER_PREFIX "Namespace") == 0) {
 				TrackerNamespace *namespace;
 
@@ -386,7 +397,7 @@ db_get_static_data (TrackerDBInterface *iface)
 	}
 
 	stmt = tracker_db_interface_create_statement (iface,
-						      "SELECT (SELECT Uri FROM \"rdfs:Resource\" WHERE ID = \"rdfs:Class\".ID) "
+						      "SELECT \"rdfs:Class\".ID, (SELECT Uri FROM \"rdfs:Resource\" WHERE ID = \"rdfs:Class\".ID) "
 						      "FROM \"rdfs:Class\" ORDER BY ID");
 	cursor = tracker_db_statement_start_cursor (stmt, NULL);
 	g_object_unref (stmt);
@@ -395,15 +406,19 @@ db_get_static_data (TrackerDBInterface *iface)
 		while (tracker_db_cursor_iter_next (cursor)) {
 			TrackerClass *class;
 			const gchar  *uri;
+			gint          id;
 			gint          count;
 
 			class = tracker_class_new ();
 
-			uri = tracker_db_cursor_get_string (cursor, 0);
+			id = tracker_db_cursor_get_int (cursor, 0);
+			uri = tracker_db_cursor_get_string (cursor, 1);
 
 			tracker_class_set_uri (class, uri);
 			class_add_super_classes_from_db (iface, class);
+
 			tracker_ontology_add_class (class);
+			tracker_ontology_add_id_uri_pair (id, uri);
 
 			/* xsd classes do not derive from rdfs:Resource and do not use separate tables */
 			if (!g_str_has_prefix (tracker_class_get_name (class), "xsd:")) {
@@ -423,14 +438,16 @@ db_get_static_data (TrackerDBInterface *iface)
 	}
 
 	stmt = tracker_db_interface_create_statement (iface,
-						      "SELECT (SELECT Uri FROM \"rdfs:Resource\" WHERE ID = \"rdf:Property\".ID), "
+						      "SELECT \"rdf:Property\".ID, (SELECT Uri FROM \"rdfs:Resource\" WHERE ID = \"rdf:Property\".ID), "
 						      "(SELECT Uri FROM \"rdfs:Resource\" WHERE ID = \"rdfs:domain\"), "
 						      "(SELECT Uri FROM \"rdfs:Resource\" WHERE ID = \"rdfs:range\"), "
 						      "\"nrl:maxCardinality\", "
 						      "\"tracker:indexed\", "
 						      "\"tracker:fulltextIndexed\", "
 						      "\"tracker:transient\", "
-						      "\"tracker:isAnnotation\" "
+						      "\"tracker:isAnnotation\", "
+						      "(SELECT 1 FROM \"rdfs:Resource_rdf:type\" WHERE ID = \"rdf:Property\".ID AND "
+						              "\"rdf:type\" = (Select ID FROM \"rdfs:Resource\" WHERE Uri = '" NRL_INVERSE_FUNCTIONAL_PROPERTY "')) "
 						      "FROM \"rdf:Property\" ORDER BY ID");
 	cursor = tracker_db_statement_start_cursor (stmt, NULL);
 	g_object_unref (stmt);
@@ -442,15 +459,17 @@ db_get_static_data (TrackerDBInterface *iface)
 			TrackerProperty *property;
 			const gchar     *uri, *domain_uri, *range_uri;
 			gboolean         multi_valued, indexed, fulltext_indexed;
-			gboolean         transient, annotation;
+			gboolean         transient, annotation, is_inverse_functional_property;
+			gint             id;
 
 			property = tracker_property_new ();
 
-			uri = tracker_db_cursor_get_string (cursor, 0);
-			domain_uri = tracker_db_cursor_get_string (cursor, 1);
-			range_uri = tracker_db_cursor_get_string (cursor, 2);
+			id = tracker_db_cursor_get_int (cursor, 0);
+			uri = tracker_db_cursor_get_string (cursor, 1);
+			domain_uri = tracker_db_cursor_get_string (cursor, 2);
+			range_uri = tracker_db_cursor_get_string (cursor, 3);
 
-			tracker_db_cursor_get_value (cursor, 3, &value);
+			tracker_db_cursor_get_value (cursor, 4, &value);
 
 			if (G_VALUE_TYPE (&value) != 0) {
 				multi_valued = (g_value_get_int (&value) > 1);
@@ -461,7 +480,7 @@ db_get_static_data (TrackerDBInterface *iface)
 				multi_valued = TRUE;
 			}
 
-			tracker_db_cursor_get_value (cursor, 4, &value);
+			tracker_db_cursor_get_value (cursor, 5, &value);
 
 			if (G_VALUE_TYPE (&value) != 0) {
 				indexed = (g_value_get_int (&value) == 1);
@@ -471,7 +490,7 @@ db_get_static_data (TrackerDBInterface *iface)
 				indexed = FALSE;
 			}
 
-			tracker_db_cursor_get_value (cursor, 5, &value);
+			tracker_db_cursor_get_value (cursor, 6, &value);
 
 			if (G_VALUE_TYPE (&value) != 0) {
 				fulltext_indexed = (g_value_get_int (&value) == 1);
@@ -481,7 +500,7 @@ db_get_static_data (TrackerDBInterface *iface)
 				fulltext_indexed = FALSE;
 			}
 
-			tracker_db_cursor_get_value (cursor, 6, &value);
+			tracker_db_cursor_get_value (cursor, 7, &value);
 
 			if (G_VALUE_TYPE (&value) != 0) {
 				transient = (g_value_get_int (&value) == 1);
@@ -491,7 +510,7 @@ db_get_static_data (TrackerDBInterface *iface)
 				transient = FALSE;
 			}
 
-			tracker_db_cursor_get_value (cursor, 7, &value);
+			tracker_db_cursor_get_value (cursor, 8, &value);
 
 			if (G_VALUE_TYPE (&value) != 0) {
 				annotation = (g_value_get_int (&value) == 1);
@@ -501,6 +520,16 @@ db_get_static_data (TrackerDBInterface *iface)
 				annotation = FALSE;
 			}
 
+			tracker_db_cursor_get_value (cursor, 8, &value);
+
+			if (G_VALUE_TYPE (&value) != 0) {
+				is_inverse_functional_property = TRUE;
+				g_value_unset (&value);
+			} else {
+				/* NULL */
+				is_inverse_functional_property = FALSE;
+			}
+
 			tracker_property_set_transient (property, transient);
 			tracker_property_set_uri (property, uri);
 			tracker_property_set_domain (property, tracker_ontology_get_class_by_uri (domain_uri));
@@ -509,8 +538,11 @@ db_get_static_data (TrackerDBInterface *iface)
 			tracker_property_set_indexed (property, indexed);
 			tracker_property_set_fulltext_indexed (property, fulltext_indexed);
 			tracker_property_set_embedded (property, !annotation);
+			tracker_property_set_is_inverse_functional_property (property, is_inverse_functional_property);
 			property_add_super_properties_from_db (iface, property);
+
 			tracker_ontology_add_property (property);
+			tracker_ontology_add_id_uri_pair (id, uri);
 
 			g_object_unref (property);
 
@@ -520,6 +552,35 @@ db_get_static_data (TrackerDBInterface *iface)
 	}
 }
 
+
+static void
+insert_uri_in_resource_table (TrackerDBInterface *iface, const gchar *uri, gint *max_id)
+{
+	TrackerDBStatement *stmt;
+	gint id = ++(*max_id);
+	GError *error = NULL;
+
+	stmt = tracker_db_interface_create_statement (iface,
+	                                              "INSERT  "
+	                                              "INTO \"rdfs:Resource\" "
+	                                              "(ID, Uri, \"tracker:added\", "
+	                                                "\"tracker:modified\", Available) "
+	                                              "VALUES (?, ?, ?, 0, 1)");
+	tracker_db_statement_bind_int (stmt, 0, id);
+	tracker_db_statement_bind_text (stmt, 1, uri);
+	tracker_db_statement_bind_int64 (stmt, 2, (gint64) time (NULL));
+	tracker_db_statement_execute (stmt, &error);
+
+	if (error) {
+		g_critical ("%s\n", error->message);
+		g_clear_error (&error);
+	}
+
+	tracker_ontology_add_id_uri_pair (id, uri);
+	g_object_unref (stmt);
+
+}
+
 static void
 create_decomposed_metadata_property_table (TrackerDBInterface *iface, 
 					   TrackerProperty   **property, 
@@ -598,7 +659,6 @@ create_decomposed_metadata_property_table (TrackerDBInterface *iface,
 	} else if (sql_type_for_single_value) {
 		*sql_type_for_single_value = sql_type;
 	}
-
 }
 
 static void
@@ -644,6 +704,9 @@ create_decomposed_metadata_tables (TrackerDBInterface *iface,
 				g_string_append_printf (sql, ", \"%s\" %s", 
 							tracker_property_get_name (*property), 
 							sql_type_for_single_value);
+				if (tracker_property_get_is_inverse_functional_property (*property)) {
+					g_string_append (sql, " UNIQUE");
+				}
 			}
 		}
 	}
@@ -675,20 +738,14 @@ create_decomposed_metadata_tables (TrackerDBInterface *iface,
 		}
 	}
 
-	g_slist_free (class_properties);
-
 	/* insert class uri in rdfs:Resource table */
 	if (tracker_class_get_uri (service) != NULL) {
-		TrackerDBStatement *stmt;
-
-		stmt = tracker_db_interface_create_statement (iface,
-							      "INSERT OR IGNORE INTO \"rdfs:Resource\" (ID, Uri, \"tracker:added\", \"tracker:modified\") VALUES (?, ?, ?, 0)");
-		tracker_db_statement_bind_int (stmt, 0, ++(*max_id));
-		tracker_db_statement_bind_text (stmt, 1, tracker_class_get_uri (service));
-		tracker_db_statement_bind_int64 (stmt, 2, (gint64) time (NULL));
-		tracker_db_statement_execute (stmt, NULL);
-		g_object_unref (stmt);
+		insert_uri_in_resource_table (iface, tracker_class_get_uri (service),
+		                              max_id);
 	}
+
+	g_slist_free (class_properties);
+
 }
 
 static void
@@ -715,7 +772,6 @@ create_decomposed_transient_metadata_tables (TrackerDBInterface *iface)
 			create_decomposed_metadata_property_table (iface, property,
 								   service_name,
 								   NULL);
-			
 		}
 	}
 }
@@ -763,6 +819,8 @@ tracker_data_manager_init (TrackerDBManagerFlags  flags,
 	if (is_first_time_index) {
 		TrackerClass **classes;
 		TrackerClass **cl;
+		TrackerProperty **properties;
+		TrackerProperty **property;
 		gint max_id = 0;
 		GList *sorted = NULL, *l;
 		gchar *test_schema_path;
@@ -829,6 +887,13 @@ tracker_data_manager_init (TrackerDBManagerFlags  flags,
 			create_decomposed_metadata_tables (iface, *cl, &max_id);
 		}
 
+		/* insert properties into rdfs:Resource table */
+		properties = tracker_ontology_get_properties ();
+		for (property = properties; *property; property++) {
+			insert_uri_in_resource_table (iface, tracker_property_get_uri (*property),
+				                      &max_id);
+		}
+
 		create_fts_table (iface);
 
 		/* store ontology in database */
