@@ -43,34 +43,40 @@ typedef enum  {
 	TRACKER_DATA_ERROR_CONSTRAINT
 } TrackerDataError;
 
-typedef void (*TrackerStatementCallback) (const gchar *subject, 
-					  const gchar *predicate, 
-					  const gchar *object,
-					  GPtrArray   *rdf_types,
-					  gpointer     user_data);
+typedef void (*TrackerStatementCallback) (const gchar *graph,
+                                          const gchar *subject, 
+                                          const gchar *predicate, 
+                                          const gchar *object,
+                                          GPtrArray   *rdf_types,
+                                          gpointer     user_data);
 typedef void (*TrackerCommitCallback)    (gpointer     user_data);
 
 GQuark   tracker_data_error_quark                   (void);
 
 /* Metadata */
-void     tracker_data_delete_resource_description   (const gchar               *uri,
+void     tracker_data_delete_resource_description   (const gchar               *graph,
+                                                     const gchar               *uri,
+                                                     GError                   **error);
+void     tracker_data_delete_statement              (const gchar               *graph,
+                                                     const gchar               *subject,
+                                                     const gchar               *predicate,
+                                                     const gchar               *object,
+                                                     GError                   **error);
+void     tracker_data_insert_statement              (const gchar               *graph,
+                                                     const gchar               *subject,
+                                                     const gchar               *predicate,
+                                                     const gchar               *object,
+                                                     GError                   **error);
+void     tracker_data_insert_statement_with_uri     (const gchar               *graph,
+                                                     const gchar               *subject,
+                                                     const gchar               *predicate,
+                                                     const gchar               *object,
+                                                     GError                   **error);
+void     tracker_data_insert_statement_with_string  (const gchar               *graph,
+                                                     const gchar               *subject,
+                                                     const gchar               *predicate,
+                                                     const gchar               *object,
                                                      GError                   **error);
-void     tracker_data_delete_statement              (const gchar               *subject,
-						     const gchar               *predicate,
-						     const gchar               *object,
-						     GError                   **error);
-void     tracker_data_insert_statement              (const gchar               *subject,
-						     const gchar               *predicate,
-						     const gchar               *object,
-						     GError                   **error);
-void     tracker_data_insert_statement_with_uri     (const gchar               *subject,
-						     const gchar               *predicate,
-						     const gchar               *object,
-						     GError                   **error);
-void     tracker_data_insert_statement_with_string  (const gchar               *subject,
-						     const gchar               *predicate,
-						     const gchar               *object,
-						     GError                   **error);
 void     tracker_data_begin_transaction             (void);
 void     tracker_data_commit_transaction            (void);
 void     tracker_data_update_sparql                 (const gchar               *update,
@@ -85,14 +91,14 @@ void     tracker_data_update_disable_all_volumes    (void);
 void     tracker_data_update_reset_volume           (const gchar               *uri);
 
 /* Calling back */
-void     tracker_data_set_insert_statement_callback (TrackerStatementCallback   callback,
-						     gpointer                   user_data);
-void     tracker_data_set_delete_statement_callback (TrackerStatementCallback   callback,
-						     gpointer                   user_data);
-void     tracker_data_set_commit_statement_callback (TrackerCommitCallback      callback,
-						     gpointer                   user_data);
-void     tracker_data_set_rollback_statement_callback (TrackerCommitCallback      callback,
-						       gpointer                   user_data);
+void     tracker_data_add_insert_statement_callback   (TrackerStatementCallback   callback,
+                                                       gpointer                   user_data);
+void     tracker_data_add_delete_statement_callback   (TrackerStatementCallback   callback,
+                                                       gpointer                   user_data);
+void     tracker_data_add_commit_statement_callback   (TrackerCommitCallback      callback,
+                                                       gpointer                   user_data);
+void     tracker_data_add_rollback_statement_callback (TrackerCommitCallback      callback,
+                                                       gpointer                   user_data);
 
 G_END_DECLS
 
