@@ -38,6 +38,16 @@
 #include <libtracker-miner/tracker-miner-manager.h>
 #include <libtracker-miner/tracker-crawler.h>
 
+#define ABOUT                                                             \
+        "Tracker " PACKAGE_VERSION "\n"
+
+#define LICENSE                                                           \
+        "This program is free software and comes without any warranty.\n" \
+        "It is licensed under version 2 or later of the General Public "  \
+        "License which can be viewed at:\n"                               \
+        "\n"                                                              \
+        "  http://www.gnu.org/licenses/gpl.txt\n"
+
 static gboolean     should_kill;
 static gboolean     should_terminate;
 static gboolean     hard_reset;
@@ -45,6 +55,7 @@ static gboolean     soft_reset;
 static gboolean     remove_config;
 static gboolean     remove_thumbnails;
 static gboolean     start;
+static gboolean     print_version;
 
 static GOptionEntry entries[] = {
 	{ "kill", 'k', 0, G_OPTION_ARG_NONE, &should_kill,
@@ -69,6 +80,9 @@ static GOptionEntry entries[] = {
 	{ "start", 's', 0, G_OPTION_ARG_NONE, &start,
 	  N_("Starts miners (which indirectly starts tracker-store too)"),
 	  NULL },
+	{ "version", 'V', 0, G_OPTION_ARG_NONE, &print_version,
+	  N_("Print version"),
+	  NULL },
 	{ NULL }
 };
 
@@ -209,6 +223,11 @@ main (int argc, char **argv)
 	g_option_context_parse (context, &argc, &argv, NULL);
 	g_option_context_free (context);
 
+	if (print_version) {
+                g_print ("\n" ABOUT "\n" LICENSE "\n");
+		return EXIT_SUCCESS;
+	}
+
 	if (should_kill && should_terminate) {
 		g_printerr ("%s\n",
 			    _("You can not use the --kill and --terminate arguments together"));
