@@ -624,8 +624,12 @@ query_mount_points_cb (TrackerMiner *miner,
 #endif
 
 			if (urn) {
-				g_debug ("URN '%s' (mount point: %s) was not reported to be mounted, but now it is, updating state",
-				         mount_point, urn);
+				if (mount_point) {
+					g_debug ("URN '%s' (mount point: %s) was not reported to be mounted, but now it is, updating state",
+						 urn, mount_point);
+				} else {
+					g_debug ("URN '%s' was not reported to be mounted, but now it is, updating state", urn);
+				}
 				set_up_mount_point (TRACKER_MINER_FILES (miner), urn, mount_point, TRUE, accumulator);
 			}
 		} else if (!(state & VOLUME_MOUNTED) &&
@@ -1213,7 +1217,6 @@ extractor_get_embedded_metadata_cb (DBusGProxy *proxy,
 	}
 
 	if (sparql) {
-		tracker_sparql_builder_insert_close (data->sparql);
 		tracker_sparql_builder_append (data->sparql, sparql);
 		g_free (sparql);
 	}
@@ -1328,6 +1331,8 @@ process_file_cb (GObject      *object,
 
         miner_files_add_to_datasource (data->miner, file, sparql);
 
+	tracker_sparql_builder_insert_close (sparql);
+
 	/* Send file/mime data to thumbnailer (which adds it to the
 	 * queue if the thumbnailer handles those mime types).
 	 */
