@@ -32,12 +32,23 @@
 #include <libtracker-client/tracker.h>
 #include <libtracker-common/tracker-common.h>
 
+#define ABOUT                                                             \
+        "Tracker " PACKAGE_VERSION "\n"
+
+#define LICENSE                                                           \
+        "This program is free software and comes without any warranty.\n" \
+        "It is licensed under version 2 or later of the General Public "  \
+        "License which can be viewed at:\n"                               \
+        "\n"                                                              \
+        "  http://www.gnu.org/licenses/gpl.txt\n"
+
 static gchar	*file;
 static gchar	*query;
 static gboolean	 update;
 static gboolean  list_classes;
 static gboolean  list_class_prefixes;
 static gchar    *list_properties;
+static gboolean  print_version;
 
 static GOptionEntry   entries[] = {
 	{ "file", 'f', 0, G_OPTION_ARG_FILENAME, &file,
@@ -64,6 +75,10 @@ static GOptionEntry   entries[] = {
 	  N_("Retrieve properties for a class, prefixes can be used too (e.g. rdfs:Resource)"),
 	  N_("CLASS"),
 	},
+	{ "version", 'V', 0, G_OPTION_ARG_NONE, &print_version,
+	  N_("Print version"),
+	  NULL,
+	},
 	{ NULL }
 };
 
@@ -161,6 +176,13 @@ main (int argc, char **argv)
 	g_option_context_add_main_entries (context, entries, NULL);
 	g_option_context_parse (context, &argc, &argv, NULL);
 
+	if (print_version) {
+                g_print ("\n" ABOUT "\n" LICENSE "\n");
+		g_option_context_free (context);
+
+		return EXIT_SUCCESS;
+	}
+
 	if (!list_classes && !list_class_prefixes && !list_properties &&
 	    ((!file && !query) || (file && query))) {
 		gchar *help;
