@@ -30,6 +30,9 @@ typedef struct {
         GList *authors;
         GList *editors;
         GList *contributors;
+        gchar *gitlog;
+        gchar *upstream;
+        gchar *copyright;
         gchar *baseUrl;
         gchar *localPrefix;
         gchar *relativePath;
